import * as codepipeline from 'aws-cdk-lib/aws-codepipeline';
import * as codepipeline_actions from 'aws-cdk-lib/aws-codepipeline-actions';
import { Construct } from 'constructs';
import { CodeGuruSeverityThreshold } from '../common';
/**
 * Props for the CodeGuruSecurityStep construct.
 *
 * @interface CodeGuruSecurityStepProps
 */
interface CodeGuruSecurityStepProps {
    /**
     * The name of the application.
     *
     * @type {string}
     */
    applicationName: string;
    /**
     * The qualifier for the application (e.g., dev, prod).
     *
     * @type {string}
     */
    applicationQualifier: string;
    /**
     * The output artifact from the source stage of the CodePipeline.
     *
     * @type {codepipeline.Artifact}
     */
    sourceOutput: codepipeline.Artifact;
    /**
     * The severity threshold for CodeGuru Security to fail the pipeline.
     *
     * @type {CodeGuruSeverityThreshold}
     */
    threshold: CodeGuruSeverityThreshold;
}
/**
 * A construct that creates a CodeBuild project and a CodePipeline action to run CodeGuru Security on the source code.
 *
 * @export
 * @class CodeGuruSecurityStep
 * @extends {Construct}
 */
export declare class CodeGuruSecurityStep extends Construct {
    /**
     * The CodePipeline action to run the CodeGuru Security scan.
     *
     * @public
     * @type {codepipeline_actions.CodeBuildAction}
     */
    readonly action: codepipeline_actions.CodeBuildAction;
    /**
     * The Docker image used for the CodeBuild project.
     *
     * @private
     * @type {string}
     * @memberof CodeGuruSecurityStep
     */
    private readonly codeGuruScanImage;
    constructor(scope: Construct, id: string, props: CodeGuruSecurityStepProps);
}
export {};
