import * as codebuild from 'aws-cdk-lib/aws-codebuild';
import * as pipelines from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
import { RepositoryConfig } from '../common';
/**
 * Configuration options for enabling pull request checks.
 */
export interface PRCheckConfig {
    /**
     * Whether to enable Amazon CodeGuru Reviewer for the repository.
     * @default false
     */
    readonly codeGuruReviewer: boolean;
    /**
     * The AWS CodeBuild build spec to use for pull request checks.
     */
    readonly buildSpec: codebuild.BuildSpec;
    /**
     * Additional options for the AWS CodeBuild project used for pull request checks.
     */
    readonly codeBuildOptions: pipelines.CodeBuildOptions;
}
/**
 * Properties for creating a new CodeCommit repository construct.
 */
export interface CodeCommitRepositoryConstructProps extends RepositoryConfig {
    /**
     * The name of the application.
     */
    readonly applicationName: string;
    /**
     * A qualifier for the application name.
     */
    readonly applicationQualifier: string;
    /**
     * Optional configuration for enabling pull request checks.
     */
    readonly pr?: PRCheckConfig;
}
/**
 * A construct for creating a new AWS CodeCommit repository with optional pull request checks.
 */
export declare class CodeCommitRepositoryConstruct extends Construct {
    /**
     * The pipeline input for the repository.
     */
    readonly pipelineInput: pipelines.IFileSetProducer;
    constructor(scope: Construct, id: string, props: CodeCommitRepositoryConstructProps);
    /**
     * Enables pull request checks for the repository.
     * @param applicationName The name of the application.
     * @param repository The CodeCommit repository.
     * @param pr The configuration options for enabling pull request checks.
     */
    private enablePrRequest;
}
