/**
 * This module imports and exports various security and optimization plugins for use within the project.
 */
import { DestroyEncryptionKeysOnDeletePlugin } from './optimization/DestroyEncryptionKeysOnDeletePlugin';
import { AccessLogsForBucketPlugin } from './security/AccessLogsForBucketPlugin';
import { DisablePublicIPAssignmentForEC2Plugin } from './security/DisablePublicIPAssignmentForEC2Plugin';
import { EncryptBucketOnTransitPlugin } from './security/EncryptBucketOnTransitPlugin';
import { EncryptCloudWatchLogGroupsPlugin } from './security/EncryptCloudWatchLogGroupsPlugin';
import { EncryptSNSTopicOnTransitPlugin } from './security/EncryptSNSTopicOnTransitPlugin';
import { RotateEncryptionKeysPlugin } from './security/RotateEncryptionKeysPlugin';
/**
 * Re-exporting all imports from the respective files for ease of access.
 */
export * from './optimization/DestroyEncryptionKeysOnDeletePlugin';
export * from './security/AccessLogsForBucketPlugin';
export * from './security/DisablePublicIPAssignmentForEC2Plugin';
export * from './security/EncryptBucketOnTransitPlugin';
export * from './security/EncryptCloudWatchLogGroupsPlugin';
export * from './security/EncryptSNSTopicOnTransitPlugin';
export * from './security/RotateEncryptionKeysPlugin';
export * from './security/LambdaDLQPlugin';
/**
 * Class containing static instances of various security and optimization plugins.
 */
export declare class Plugins {
    /**
     * Static instance of the DestroyEncryptionKeysOnDeletePlugin.
     */
    static readonly DestroyEncryptionKeysOnDeletePlugin: DestroyEncryptionKeysOnDeletePlugin;
    /**
     * Static instance of the AccessLogsForBucketPlugin.
     */
    static readonly AccessLogsForBucketPlugin: AccessLogsForBucketPlugin;
    /**
     * Static instance of the DisablePublicIPAssignmentForEC2Plugin.
     */
    static readonly DisablePublicIPAssignmentForEC2Plugin: DisablePublicIPAssignmentForEC2Plugin;
    /**
     * Static instance of the EncryptBucketOnTransitPlugin.
     */
    static readonly EncryptBucketOnTransitPlugin: EncryptBucketOnTransitPlugin;
    /**
     * Static instance of the EncryptCloudWatchLogGroupsPlugin.
     */
    static readonly EncryptCloudWatchLogGroupsPlugin: EncryptCloudWatchLogGroupsPlugin;
    /**
     * Static instance of the EncryptSNSTopicOnTransitPlugin.
     */
    static readonly EncryptSNSTopicOnTransitPlugin: EncryptSNSTopicOnTransitPlugin;
    /**
     * Static instance of the RotateEncryptionKeysPlugin.
     */
    static readonly RotateEncryptionKeysPlugin: RotateEncryptionKeysPlugin;
}
