import * as projen from 'projen';
import { SecurityScanOptions } from './CICommands';
/**
 * Represents the type of repository for the project.
 */
export type REPOSITORY_TYPE = 'GITHUB' | 'CODECOMMIT';
/**
 * Options for configuring the CdkCICDWrapper component.
 */
export interface CdkCICDWrapperOptions {
    /**
     * CDK Qualifier used to bootstrap your project.
     */
    cdkQualifier: string;
    /**
     * The name of the repository.
     * @default project name
     */
    repositoryName?: string;
    /**
     * The type of repository.
     * @default 'CODECOMMIT'
     */
    repositoryType?: REPOSITORY_TYPE;
    cicdVpcType?: 'NO_VPC' | 'VPC' | 'VPC_FROM_LOOK_UP';
    cicdVpcId?: string;
    cicdVpcCidr?: string;
    cicdVpcCidrMask?: string;
    cicdVpcMaxAZs?: number;
    securityScan?: boolean;
    securityScanOptions?: SecurityScanOptions;
    stages?: string[];
    workbenchStage?: string;
    taskfile?: boolean;
    devbox?: boolean;
}
/**
 * A component that wraps the CDK CI/CD pipeline for a project.
 */
export declare class CdkCICDWrapper extends projen.Component {
    /**
     * The CDK Qualifier used to bootstrap the project.
     */
    readonly cdkQualifier: string;
    /**
     * The name of the repository.
     */
    readonly repositoryName: string;
    /**
     * The type of repository.
     */
    readonly repositoryType: REPOSITORY_TYPE;
    readonly stages: string[];
    readonly workbenchStage: string;
    constructor(project: projen.awscdk.AwsCdkTypeScriptApp, options: CdkCICDWrapperOptions);
}
