import { ResourceContext, IResourceProvider, Scope } from '../common';
/**
 * Compliance Bucket configuration interface.
 * This interface defines the configuration properties for a compliance bucket.
 */
export interface IComplianceBucket {
    /**
     * The name of the compliance bucket.
     */
    readonly bucketName: string;
}
/**
 * Compliance bucket provider options.
 */
export interface ComplianceBucketProviderOptions {
    /**
     * Run the Custom resource on the VPC.
     *
     * @default false
     */
    readonly runOnVpc?: boolean;
}
/**
 * Compliance bucket provider which uses existing previously created buckets.
 * This class is responsible for providing a compliance bucket resource using an existing bucket.
 */
export declare class ComplianceBucketProvider implements IResourceProvider {
    readonly runOnVpc: boolean;
    /**
     * The scope of the provider, which is set to PER_STAGE by default.
     * This means that the provider will create a separate resource for each stage.
     */
    scope?: Scope | undefined;
    constructor(options?: ComplianceBucketProviderOptions);
    /**
     * Provides the compliance bucket resource based on the given context.
     *
     * @param context The resource context containing environment information and blueprint properties.
     * @returns The ComplianceLogBucketStack instance representing the compliance bucket resource.
     */
    provide(context: ResourceContext): any;
}
