import * as kms from 'aws-cdk-lib/aws-kms';
import { IConstruct } from 'constructs';
import { ResourceContext, IResourceProvider, Scope } from '../common';
/**
 * Interface representing a construct for supplying an encryption key.
 */
export interface IEncryptionKey extends IConstruct {
    /**
     * The KMS Key used for encryption.
     */
    readonly kmsKey: kms.Key;
}
/**
 * A provider for encryption resources that creates dedicated encryption stacks in each stage.
 */
export declare class EncryptionProvider implements IResourceProvider {
    scope?: Scope | undefined;
    /**
     * Provides the encryption resources based on the given context.
     *
     * @param context The resource context containing information about the current scope, blueprint properties, stage, and environment.
     * @returns The EncryptionStack construct containing the encryption resources.
     */
    provide(context: ResourceContext): any;
}
