import * as iam from 'aws-cdk-lib/aws-iam';
import * as ssm from 'aws-cdk-lib/aws-ssm';
import { IConstruct } from 'constructs';
import { ResourceContext, IResourceProvider } from '../common';
/**
 * Construct to supply persistent parameters for IaaC code
 */
export interface IParameterConstruct extends IConstruct {
    /**
     * Create a parameter that is accessible through the pipeline
     *
     * @param parameterName - name of the parameter
     * @param parameterValue - value of the parameter
     */
    createParameter(parameterName: string, parameterValue: string): ssm.IStringParameter;
    /**
     * Returns with a policy that allows access to the parameters
     */
    provideParameterPolicyStatement(): iam.PolicyStatement;
}
/**
 * Resource provider that creates Parameters in AWS Systems Manager (SSM)
 */
export declare class ParameterProvider implements IResourceProvider {
    /**
     * Provides the resources (SSM parameters) based on the given context
     *
     * @param context - The context that contains scope, blueprint properties, and environment
     * @returns The SSMParameterStack instance
     */
    provide(context: ResourceContext): any;
}
