import { ResourceContext, IResourceProvider } from '../common';
/**
 * HTTP(s) Proxy configuration
 */
export interface IProxyConfig {
    /**
     * The ARN of the Secrets Manager secret that contains the proxy credentials.
     */
    proxySecretArn: string;
    /**
     * A list of URLs or IP addresses that should bypass the proxy.
     */
    noProxy: string[];
    /**
     * A URL to test the proxy configuration.
     */
    proxyTestUrl: string;
}
/**
 * Provides HTTPProxy settings for the pipeline.
 */
export declare class HttpProxyProvider implements IResourceProvider {
    readonly proxy: IProxyConfig;
    /**
     * Creates a new instance of the HttpProxyProvider class.
     * @param proxy The proxy configuration. If not provided, the default configuration will be used.
     */
    constructor(proxy?: IProxyConfig);
    /**
     * Provides the proxy configuration for the pipeline.
     * @param context The resource context.
     * @returns The proxy configuration.
     */
    provide(context: ResourceContext): any;
}
