import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { ResourceContext, IResourceProvider, Scope } from '../common';
/**
 * VPC Configuration for new VPC
 */
export interface IManagedVpcConfig {
    /**
     * CIDR block for the VPC. default is: 172.31.0.0/20
     */
    cidrBlock: string;
    /**
     * Subnets CIDR masks. default is: 24
     */
    subnetCidrMask: number;
    /**
     * Max AZs. default is: 2
     */
    maxAzs: number;
}
/**
 * VPC Configuration for VPC id lookup
 */
export interface IVpcConfigFromLookUp {
    /**
     * VPC id to lookup
     */
    vpcId: string;
}
/**
 * Interface representing VPC configuration
 */
export interface IVpcConfig {
    managedVPC?: IManagedVpcConfig;
    vpcFromLookUp?: string;
}
/**
 * VPC construct that provides the VPC and HTTP proxy settings
 */
export interface IVpcConstruct {
    readonly vpc?: ec2.IVpc;
    readonly securityGroup?: ec2.ISecurityGroup;
    readonly subnetType?: ec2.SubnetType;
}
/**
 * Legacy VPC Provider that defines the VPC used by the CI/CD process
 */
export declare class VPCProvider implements IResourceProvider {
    readonly legacyConfig: IVpcConfig;
    scope?: Scope | undefined;
    constructor(legacyConfig?: IVpcConfig);
    /**
     * Provides the VPC resource
     * @param context The resource context
     * @returns The VPC stack
     */
    provide(context: ResourceContext): any;
}
