import * as cdk from 'aws-cdk-lib';
import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
/**
 * Properties for the PostDeployExecutorStack.
 */
export interface PostDeployExecutorStackProps extends cdk.StackProps {
    /**
     * The prefix to use for resource names.
     */
    readonly prefix?: string;
    /**
     * The AWS account ID where the resources will be deployed.
     */
    readonly resAccount: string;
    /**
     * The name of the deployment stage (e.g., 'prod', 'test').
     */
    readonly stageName: string;
    /**
     * The name of the application.
     */
    readonly name: string;
    /**
     * A list of named policies to inline into this role. These policies will be
     * created with the role, whereas those added by ``addToPolicy`` are added
     * using a separate CloudFormation resource (allowing a way around circular
     * dependencies that could otherwise be introduced).
     *
     * @default - No policy is inlined in the Role resource.
     */
    readonly inlinePolicies?: {
        [name: string]: iam.PolicyDocument;
    };
}
/**
 * Stack for creating an IAM role used for Post Deploy command executions.
 */
export declare class PostDeployExecutorStack extends cdk.Stack {
    static readonly POST_DEPLOY_ROLE_ARN = "postDeployRoleArn";
    /**
     * The prefix to use for resource names.
     */
    readonly prefix: string;
    /**
     * The AWS account ID where the resources will be deployed.
     */
    readonly resAccount: string;
    /**
     * The name of the deployment stage (e.g., 'prod', 'test').
     */
    readonly stageName: string;
    /**
     * The name of the application.
     */
    readonly name: string;
    /**
     * The name of the created IAM role.
     */
    readonly roleName: string;
    /**
     * The ARN of the created IAM role.
     */
    readonly roleArn: string;
    /**
     * The IAM role used for Post Deploy command executions.
     */
    readonly role: iam.Role;
    constructor(scope: Construct, id: string, props: PostDeployExecutorStackProps);
    /**
     * Generates the name for the IAM role based on the provided parameters.
     *
     * @returns The generated role name.
     */
    private generate;
}
