import * as cdk from 'aws-cdk-lib';
import * as iam from 'aws-cdk-lib/aws-iam';
import * as ssm from 'aws-cdk-lib/aws-ssm';
import { Construct } from 'constructs';
/**
 * Properties for the SSMParameterStack.
 */
export interface SSMParameterStackProps extends cdk.StackProps {
    /**
     * The qualifier to use for the application.
     */
    readonly applicationQualifier: string;
    /**
     * An optional object containing key-value pairs representing the parameters to create in the SSM Parameter Store.
     * @default - No parameters are created.
     */
    readonly parameter?: {
        [key: string]: string;
    };
}
/**
 * A stack for creating and managing AWS Systems Manager (SSM) Parameters.
 */
export declare class SSMParameterStack extends cdk.Stack {
    readonly applicationQualifier: string;
    constructor(scope: Construct, id: string, props: SSMParameterStackProps);
    /**
     * Creates a new String Parameter in the SSM Parameter Store within this stack.
     *
     * @param parameterName - The name of the parameter.
     * @param parameterValue - The value of the parameter.
     * @returns The created SSM String Parameter resource.
     */
    createParameterInSSMParameterStack(parameterName: string, parameterValue: string): ssm.StringParameter;
    /**
     * Creates a new String Parameter in the SSM Parameter Store within the provided scope.
     *
     * @param scope - The scope in which to create the parameter.
     * @param parameterName - The name of the parameter.
     * @param parameterValue - The value of the parameter.
     * @returns The created SSM String Parameter resource.
     */
    createParameter(scope: Construct, parameterName: string, parameterValue: string): ssm.StringParameter;
    /**
     * Provides an IAM Policy Statement that grants permissions to retrieve parameters from the SSM Parameter Store.
     *
     * @returns The IAM Policy Statement granting access to the SSM Parameters.
     */
    provideParameterPolicyStatement(): iam.PolicyStatement;
}
