import * as cdk from 'aws-cdk-lib';
import { ISecurityGroup, IVpc, SubnetSelection } from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
import { IComplianceBucket } from '../../resource-providers';
/**
 * Properties for the ComplianceLogBucketStack.
 */
export interface ComplianceLogBucketStackProps extends cdk.StackProps {
    /**
     * The name of the compliance log bucket to be created.
     */
    readonly complianceLogBucketName: string;
    /**
     * The vpc where the ComplianceLogBucket CR Lambda must be attached to
     */
    readonly vpc?: IVpc;
    /**
     * The security group of the vpc
     */
    readonly securityGroup?: ISecurityGroup;
    /**
     * The subnet selection of the vpc
     */
    readonly subnetSelection?: SubnetSelection;
}
/**
 * Stack for creating a compliance log bucket.
 * Implements the IComplianceBucketConfig interface to provide the bucket name.
 */
export declare class ComplianceLogBucketStack extends cdk.Stack implements IComplianceBucket {
    /**
     * The name of the bucket created by this stack.
     */
    readonly bucketName: string;
    readonly vpc?: IVpc;
    readonly securityGroup?: ISecurityGroup;
    readonly subnetSelection?: SubnetSelection;
    /**
     * Constructs a new instance of the ComplianceLogBucketStack.
     *
     * @param scope The scope in which to define this construct.
     * @param id The unique identifier for this construct.
     * @param props The properties for the ComplianceLogBucketStack.
     */
    constructor(scope: Construct, id: string, props: ComplianceLogBucketStackProps);
    createVpcConfig(): object | undefined;
}
