import * as cdk from 'aws-cdk-lib';
import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { Construct } from 'constructs';
/**
 * Properties for the VPCStack.
 */
export interface VPCFromLookUpStackProps extends cdk.StackProps {
    /**
     * The configuration for the VPC to be created or looked up.
     */
    readonly vpcId: string;
    /**
     * The list of CodeBuild VPC InterfacesVpcEndpointAwsServices to extend the defaultCodeBuildVPCInterfaces
     */
    readonly codeBuildVPCInterfaces?: ec2.InterfaceVpcEndpointAwsService[];
}
/**
 * A stack that creates or looks up a VPC and configures its settings.
 */
export declare class VPCFromLookUpStack extends cdk.Stack {
    /**
     * The VPC created or looked up by this stack.
     */
    readonly vpc: ec2.IVpc;
    /**
     * The security group attached to the VPC
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * The subnets attached to the VPC
     */
    readonly subnetType?: ec2.SubnetType;
    /**
     * The list of CodeBuild VPC InterfacesVpcEndpointAwsServices
     */
    readonly codeBuildVPCInterfaces: ec2.InterfaceVpcEndpointAwsService[];
    /**
     * The ID of the VPC being created or looked up.
     */
    readonly vpcId: string;
    constructor(scope: Construct, id: string, props: VPCFromLookUpStackProps);
}
